@@ -1,15 +1,16 @@
-/* charge.h -- This file is part of Archimedes release 0.0.7.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
+/* charge.h -- This file is part of Archimedes release 0.1.2
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for
    electrons. It also includes the quantum effects by means 
-   of Bohm effective potential method.
+   of Bohm effective potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,15 +19,14 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 
 // ######################################################
 // Created on 06 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 27 Dec.2006, Siracusa, J.M.Sellier
+// Last modif. : 12 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // computation of the macroscopic variables
@@ -42,9 +42,9 @@ Charge(void)
 // a simple way to avoid NaN propagation...
  for(i=1;i<=nx+1;i++)
    for(j=1;j<=ny+1;j++)
-     u2d[i][j][1]=DG[i][j]=DL[i][j]=0.;
+     u2d[i][j][1]=0.;
 
-if(Material==SILICON || Material==GERMANIUM){
+//if(Material==SILICON || Material==GERMANIUM){
 // well known "cloud in cell" method
   for(n=1;n<=INUM;n++){
     x=P[n][5]/dx;
@@ -75,8 +75,8 @@ if(Material==SILICON || Material==GERMANIUM){
 // bottom and upper edge contacts
   u2d[nx+1][ny+1][1]=u2d[nx][ny+1][1];
   u2d[1][ny+1][1]=u2d[1][ny][1];
- }
-if(Material==GAAS){
+// }
+/*if(Material==GAAS){
 // well known "cloud in cell" method
   for(n=1;n<=INUM;n++){
     x=P[n][5]/dx;
@@ -131,7 +131,7 @@ if(Material==GAAS){
 // bottom and upper edge contacts
   u2d[nx+1][ny+1][1]=u2d[nx][ny+1][1];
   u2d[1][ny+1][1]=u2d[1][ny][1];
- }
+ }*/
 }
 
 // ===========================================================
